==> jc-1.4.0.tar.gz: java/rmi/activation/ActivationException.h <==
// public class java.rmi.activation.ActivationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fd8995a120b8f60d java_rmi_activation_ActivationException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_rmi_activation_ActivationException_H_
#define _JC_java_rmi_activation_ActivationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_rmi_activation_ActivationException$sub_refs	_jc_java_rmi_activation_ActivationException$sub_refs;
typedef struct _jc_java_rmi_activation_ActivationException$sub_nonrefs	_jc_java_rmi_activation_ActivationException$sub_nonrefs;
typedef struct _jc_java_rmi_activation_ActivationException$refs	_jc_java_rmi_activation_ActivationException$refs;
typedef struct _jc_java_rmi_activation_ActivationException$nonrefs	_jc_java_rmi_activation_ActivationException$nonrefs;
typedef struct _jc_java_rmi_activation_ActivationException$object	_jc_java_rmi_activation_ActivationException$object;

typedef struct _jc_java_rmi_activation_ActivationException$fields_struct	_jc_java_rmi_activation_ActivationException$fields_struct;
typedef const struct _jc_java_rmi_activation_ActivationException$vmethods	_jc_java_rmi_activation_ActivationException$vmethods;
typedef const struct _jc_java_rmi_activation_ActivationException$vtable	_jc_java_rmi_activation_ActivationException$vtable;
typedef const struct _jc_java_rmi_activation_ActivationException$vtype	_jc_java_rmi_activation_ActivationException$vtype;

// Class fields structure
struct _jc_java_rmi_activation_ActivationException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_activation_ActivationException$fields_struct _jc_java_rmi_activation_ActivationException$class_fields;

// Constructors
extern void _jc_java_rmi_activation_ActivationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_activation_ActivationException$object *);
extern void _jc_java_rmi_activation_ActivationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_activation_ActivationException$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_rmi_activation_ActivationException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_rmi_activation_ActivationException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_rmi_activation_ActivationException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_rmi_activation_ActivationException$object *);
extern struct _jc_java_lang_String$object *_jc_java_rmi_activation_ActivationException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_rmi_activation_ActivationException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_rmi_activation_ActivationException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_rmi_activation_ActivationException$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_java_rmi_activation_ActivationException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_rmi_activation_ActivationException$object *);
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_rmi_activation_ActivationException$object *);
};

// Vtable
struct _jc_java_rmi_activation_ActivationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_rmi_activation_ActivationException$vmethods	java_rmi_activation_ActivationException;
};

// Vtype
struct _jc_java_rmi_activation_ActivationException$vtype {
	_jc_type			type;
	_jc_java_rmi_activation_ActivationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationException$sub_refs {
	struct _jc_java_lang_Throwable$object	*detail;
};

// Reference instance fields (object)
struct _jc_java_rmi_activation_ActivationException$refs {
    _jc_java_rmi_activation_ActivationException$sub_refs	java_rmi_activation_ActivationException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_activation_ActivationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_rmi_activation_ActivationException$sub_nonrefs	java_rmi_activation_ActivationException;
};

// Object instance structure
struct _jc_java_rmi_activation_ActivationException$object {
	_jc_java_rmi_activation_ActivationException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_activation_ActivationException$vtype	*vtype;
	_jc_java_rmi_activation_ActivationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_activation_ActivationException$vtype _jc_java_rmi_activation_ActivationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_activation_ActivationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_activation_ActivationException$class_object;

#endif	/* _JC_java_rmi_activation_ActivationException_H_ */

==> jc-1.4.6.tar.gz: java/rmi/activation/ActivationException.h <==
// public class java.rmi.activation.ActivationException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class fd8995a120b8f60d java_rmi_activation_ActivationException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_rmi_activation_ActivationException_H_
#define _JC_java_rmi_activation_ActivationException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_rmi_activation_ActivationException$sub_refs	_jc_java_rmi_activation_ActivationException$sub_refs;
typedef struct _jc_java_rmi_activation_ActivationException$sub_nonrefs	_jc_java_rmi_activation_ActivationException$sub_nonrefs;
typedef struct _jc_java_rmi_activation_ActivationException$refs	_jc_java_rmi_activation_ActivationException$refs;
typedef struct _jc_java_rmi_activation_ActivationException$nonrefs	_jc_java_rmi_activation_ActivationException$nonrefs;
typedef struct _jc_java_rmi_activation_ActivationException$object	_jc_java_rmi_activation_ActivationException$object;

typedef struct _jc_java_rmi_activation_ActivationException$fields_struct	_jc_java_rmi_activation_ActivationException$fields_struct;
typedef const struct _jc_java_rmi_activation_ActivationException$vmethods	_jc_java_rmi_activation_ActivationException$vmethods;
typedef const struct _jc_java_rmi_activation_ActivationException$vtable	_jc_java_rmi_activation_ActivationException$vtable;
typedef const struct _jc_java_rmi_activation_ActivationException$vtype	_jc_java_rmi_activation_ActivationException$vtype;

// Class fields structure
struct _jc_java_rmi_activation_ActivationException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_rmi_activation_ActivationException$fields_struct _jc_java_rmi_activation_ActivationException$class_fields;

// Constructors
extern void _jc_java_rmi_activation_ActivationException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_rmi_activation_ActivationException$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_activation_ActivationException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_rmi_activation_ActivationException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_rmi_activation_ActivationException$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_rmi_activation_ActivationException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_rmi_activation_ActivationException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_rmi_activation_ActivationException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_rmi_activation_ActivationException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_rmi_activation_ActivationException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_rmi_activation_ActivationException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_rmi_activation_ActivationException$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_java_rmi_activation_ActivationException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_rmi_activation_ActivationException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_rmi_activation_ActivationException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_rmi_activation_ActivationException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_rmi_activation_ActivationException$vmethods	java_rmi_activation_ActivationException;
};

// Vtype
struct _jc_java_rmi_activation_ActivationException$vtype {
	_jc_type			type;
	_jc_java_rmi_activation_ActivationException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationException$sub_refs {
	struct _jc_java_lang_Throwable$object	*detail;
};

// Reference instance fields (object)
struct _jc_java_rmi_activation_ActivationException$refs {
    _jc_java_rmi_activation_ActivationException$sub_refs	java_rmi_activation_ActivationException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_rmi_activation_ActivationException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_rmi_activation_ActivationException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_rmi_activation_ActivationException$sub_nonrefs	java_rmi_activation_ActivationException;
};

// Object instance structure
struct _jc_java_rmi_activation_ActivationException$object {
	_jc_java_rmi_activation_ActivationException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_rmi_activation_ActivationException$vtype	*vtype;
	_jc_java_rmi_activation_ActivationException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_rmi_activation_ActivationException$vtype _jc_java_rmi_activation_ActivationException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_rmi_activation_ActivationException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_rmi_activation_ActivationException$class_object;

#endif	/* _JC_java_rmi_activation_ActivationException_H_ */
